@@ -2,9 +2,11 @@ from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import scoped_session, sessionmaker
 
 
-Session = sessionmaker(autoflush=True)
+Session = None
 
 def initialize_sql(engine):
+    global Session
+    Session = sessionmaker(autoflush=True)
     #if Session.registry.has(): return Session
     #Session = scoped_session(sessionmaker(bind=engine))
     session = Session(bind=engine)
